# Welcome to the Reports plugin

## Usage

In this panel you can see the rendered output of report files, i.e: Markdown
files or files with the `mdw` extension, that contain code, text,
mathematical equations and graphics. It uses the the
[Pweave](http://mpastell.com/pweave/) project to generate the reports.

Please use the _Run > Render report to HTML_ menu entry to render a report.

Reports are rendered in a temporary location, if you want to save them
use the tooltip menu.